<?php
/**
 * The core plugin class.
 *
 * This is used to define internationalization, dashboard-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Legal_Manager
 * @subpackage Legal_Manager/includes
 * @author:    UlisesFreitas <ulises.freitas@gmail.com>
 */
class Legal_Manager {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Legal_Manager_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $Legal_Manager    The string used to uniquely identify this plugin.
	 */
	protected $Legal_Manager;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

    
    
    
	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the Dashboard and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {

        if ( defined( 'LEGAL_MANAGER_VERSION' ) ) {
			$this->version = LEGAL_MANAGER_VERSION;
		} else {
			$this->version = '1.0.0';
		}
        if( defined('LEGAL_MANAGER_PLUGIN_NAME') ){
            $this->plugin_name = LEGAL_MANAGER_PLUGIN_NAME;
        }else{
            $this->plugin_name = 'legal-manager';
        }
		
		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

    
	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Legal_Manager_Loader. Orchestrates the hooks of the plugin.
	 * - Legal_Manager_i18n. Defines internationalization functionality.
	 * - Legal_Manager_Admin. Defines all hooks for the dashboard.
	 * - Legal_Manager_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {
        
		//Includes
		require_once LEGAL_MANAGER_PATH . 'includes/class-legal-manager-loader.php';
		require_once LEGAL_MANAGER_PATH . 'includes/class-legal-manager-i18n.php';
		//Public
		require_once LEGAL_MANAGER_PATH . 'public/class-legal-manager-public.php';

		//Admin
		require_once LEGAL_MANAGER_PATH . 'admin/class-legal-manager-admin.php';
        require_once LEGAL_MANAGER_PATH . 'admin/class-legal-manager-wizard.php';

		//Vendors
		require_once LEGAL_MANAGER_PATH . 'vendor/wizard/legal-wizard.php';
		

		$this->loader = new Legal_Manager_Loader();

	}
    
    
	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Legal_Manager_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Legal_Manager_i18n();
		$plugin_i18n->set_domain( $this->get_plugin_name() );

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the dashboard functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Legal_Manager_Admin( $this->get_plugin_name(), $this->get_version() );
		//$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		//$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_filter( 'plugin_row_meta', $plugin_admin,'legal_manager_plugin_meta_links', 10, 2);
		
        $plugin_wizard = new Legal_Manager_Wizard();
        $this->loader->add_action( 'legal_wizard_setup', $plugin_wizard, 'legal_manager_wizard_setup'  );
        $this->loader->add_action( 'legal_wizard_register', $plugin_wizard, 'legal_manager_wizard_register'  );
        
       
        
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		//$plugin_public = new Legal_Manager_Public( $this->get_plugin_name(), $this->get_version() );
		//$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		//$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
          
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Legal_Manager_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
